# Hogeland Linux - Linux Migratie Service Website

Een Nederlandse website voor Linux migratie services in lijn met de endof10.org beweging.

## Overzicht

Deze website helpt mensen bij het migreren van Windows 10 naar Linux, met focus op:
- Duurzaam computergebruik en het voorkomen van e-waste
- Voordelen van FOSS (Free and Open Source Software)
- Hergebruik van oude hardware
- Professionele Linux installatie services

## Technische Details

- **Backend**: Go met html/template
- **Frontend**: Modern CSS met responsive design
- **Stijl**: Minimalistisch en toegankelijk voor alle leeftijden
- **Taal**: Nederlands

## Installatie en Gebruik

### Vereisten
- Go 1.24.4 of hoger
- Moderne webbrowser

### Website Starten

```bash
# Start de server
go run main.go

# De website is nu beschikbaar op:
# http://localhost:8080
```

### Structuur
```
linuxservice/
├── main.go           # Go webserver
├── templates/        # HTML templates
│   ├── index.html   # Hoofdpagina
│   └── contact.html # Contact pagina
├── static/          # Statische bestanden
│   └── style.css   # CSS styling
└── README.md        # Dit bestand
```

## Aanpassing Contactgegevens

Om uw eigen contactgegevens in te vullen, pas de volgende waarden aan in `main.go`:

```go
// Vervang deze waarden met uw eigen gegevens:
KVK:         "12345678",              // Uw KVK nummer
Email:       "info@hogelandlinux.nl",  // Uw email adres
Phone:       "+31 6 12345678",        // Uw telefoonnummer
```

## Pagina's

### Hoofdpagina (/)
- Hero sectie met duidelijke call-to-action
- Voordelen van Linux migratie
- Informatie over Windows 10 End of Life
- Linux distributies showcase met aanbevelingen
- Linux features met visuele mockups
- Diensten overzicht
- Call-to-action

### Contact Pagina (/contact)
- Contactformulier
- Bedrijfsinformatie
- Openingstijden
- Waarom klanten voor u moeten kiezen

## Styling

Het design is:
- **Minimalistisch**: Schoon en overzichtelijk
- **Toegankelijk**: Geschikt voor alle leeftijden
- **Responsive**: Werkt op desktop, tablet en mobiel
- **Professioneel**: Vertrouwen opwekkend voor bedrijven
- **Eco-vriendelijk**: Groene kleurenpalet die duurzaamheid benadrukt
- **Tech-georiënteerd**: Visuele mockups en functionaliteit demonstraties

## Technische Features

### Visual Elements
- **Clean Design**: Moderne en professionele interface zonder technische complexiteit
- **Distro Showcase**: 6 populaire Linux distributies met doelgroepen
- **Desktop Mockups**: Visuele representaties van Linux interfaces
- **Performance Vergelijkingen**: Grafische weergave van Linux vs Windows prestaties
- **Responsive Design**: Optimaal op alle apparaten

### Linux Distributies
De website toont:
- **Ubuntu**: Voor beginners en algemeen gebruik
- **Linux Mint**: Voor Windows gebruikers die overstappen
- **Pop!_OS**: Voor gamers en developers
- **Elementary OS**: Voor Mac gebruikers en designers
- **Fedora**: Voor tech enthusiasts en IT professionals
- **Garuda Linux**: Voor power users en performance enthusiasts

## Belangrijke Boodschappen

De website benadrukt:
- **Duurzaamheid**: Tegengaan van e-waste
- **Kostenbesparing**: Gratis Linux vs dure Windows licenties
- **Veiligheid**: Linux is veiliger dan Windows
- **Hardware hergebruik**: Oude computers krijgen nieuw leven
- **Privacy**: Geen tracking of gegevensverzameling

## Deployment

Voor productie gebruik:
1. Vervang alle placeholder contactgegevens
2. Configureer een reverse proxy (nginx/Apache)
3. Gebruik HTTPS certificaten
4. Overweeg een proper database voor contactformulieren

## Ondersteuning

Deze website ondersteunt de [endof10.org](https://endof10.org) beweging voor duurzaam computergebruik.

## Licentie

Open source - voel je vrij om aan te passen voor eigen gebruik. 